! $Id: Variables.f90 1067 2013-10-07 10:02:37Z ian $
! ff08 source code copyright 2012 M.E.G.M.S.  See LICENCE.txt for licence.
!> @file
!! Defines the Variables module.


!*******************************************************************************
!!
!> Procedures and types for parsing variables.
!!
!! Similar to expressions, variables appear everywhere, so this module 
!! has limited dependencies and relies upon external procedures to do some 
!! of the work.
!!
!! The F2008 language rules mean that all variables look like expressions, 
!! (whether that be an expression that is simply a primary that is a 
!! designator, or a function with a data pointer result), so we just piggy 
!! back off the expression type and parsing code.  In future we may do more.
!!
!! Note that the definition of a variable is subject to interpretations 
!! F08/0075 and similar.

MODULE Variables
  
  USE Expressions, ONLY: ParseVariable => ParseExpr, Variable => Expression
  
  PRIVATE
  
  PUBLIC :: ParseVariable
  PUBLIC :: WriteVariable
  
  PUBLIC :: Variable
  
CONTAINS
  
  !*****************************************************************************
  !!
  !> Write a debugging representation of a /variable/ to a formatted 
  !! file.
  !!
  !! @param[in]     log_unit          Logical unit connected for formatted 
  !! output.
  !!
  !! @param[in]     var               The /variable/ to output.
  !!
  !! This is just a wrapper for WriteExpression.
  
  SUBROUTINE WriteVariable(log_unit, var)
    
    USE Expressions
    
    !---------------------------------------------------------------------------
    ! Arguments
    
    INTEGER, INTENT(IN) :: log_unit
    CLASS(Variable), INTENT(IN) :: var
    
    !***************************************************************************
    
    CALL WriteExpr(log_unit, var)
    
  END SUBROUTINE WriteVariable
  
END MODULE Variables
